@@ -1,8 +1,8 @@
 /* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/nsc/durango.c,v 1.4 2003/01/14 09:34:30 alanh Exp $ */
 /*
  * $Workfile: durango.c $
- * $Revision: 1.3 $
- * $Author: daniels $
+ * $Revision$
+ * $Author$
  *
  * This is the main file used to add Durango graphics support to a software 
  * project.  The main reason to have a single file include the other files
@@ -311,221 +311,6 @@ unsigned char *gfx_phys_vipptr = (unsigned char *)0x40015000;
  * routines will work properly. 
  */
 
-#if defined(OS_WIN32)			/* For Windows */
-
-/* VSA II CALL */
-
-void
-gfx_msr_asm_read(unsigned short msrReg, unsigned long msrAddr,
-		 unsigned long *ptrHigh, unsigned long *ptrLow)
-{
-   unsigned long temp1, temp2;
-
-   _asm {
-      mov dx, 0x0AC1C
-      mov eax, 0x0FC530007
-      out dx, eax 
-      add dl, 2 
-      mov ecx, msrAddr 
-      mov cx, msrReg 
-      in ax, dx;
-      ;EDX:EAX will contain MSR contents.
-      mov temp1, edx 
-      mov temp2, eax
-   }
-
-   *ptrHigh = temp1;
-   *ptrLow = temp2;
-}
-
-void
-gfx_msr_asm_write(unsigned short msrReg, unsigned long msrAddr,
-		  unsigned long *ptrHigh, unsigned long *ptrLow)
-{
-   unsigned long temp1 = *ptrHigh;
-   unsigned long temp2 = *ptrLow;
-
-   _asm {
-      mov dx, 0x0AC1C
-      mov eax, 0x0FC530007 
-      out dx, eax i
-      add dl, 2 
-      ;ECX contains msrAddr | msrReg 
-      mov ecx, msrAddr
-      mov cx, msrReg
-      ;<OR_mask_hi > 
-      mov ebx, temp1
-
-      ;<OR_mask_hi > 
-      mov eax, temp2
-      ;<AND_mask_hi > 
-      mov esi, 0
-      ;<AND_mask_lo > 
-      mov edi, 0
-      ;MSR is written at this point
-      out dx, ax
-   }
-}
-
-unsigned char
-gfx_inb(unsigned short port)
-{
-   unsigned char data;
-
-   _asm {
-      pushf 
-      mov dx, port 
-      in al, dx 
-      mov data, al 
-      popf
-   }
-   return (data);
-}
-
-unsigned short
-gfx_inw(unsigned short port)
-{
-   unsigned short data;
-
-   _asm {
-      pushf 
-      mov dx, port 
-      in ax, dx 
-      mov data, ax 
-      popf
-   }
-   return (data);
-}
-
-unsigned long
-gfx_ind(unsigned short port)
-{
-   unsigned long data;
-
-   _asm {
-      pushf 
-      mov dx, port 
-      in eax, dx 
-      mov data, eax 
-      popf
-   }
-   return (data);
-}
-
-void
-gfx_outb(unsigned short port, unsigned char data)
-{
-   _asm {
-      pushf 
-      mov al, data 
-      mov dx, port 
-      out dx, al 
-      popf
-   }
-}
-
-void
-gfx_outw(unsigned short port, unsigned short data)
-{
-   _asm {
-      pushf 
-      mov ax, data 
-      mov dx, port 
-      out dx, ax 
-      popf
-   }
-}
-
-void
-gfx_outd(unsigned short port, unsigned long data)
-{
-   _asm {
-      pushf 
-      mov eax, data 
-      mov dx, port 
-      out dx, eax 
-      popf
-   }
-}
-
-#elif defined(OS_VXWORKS) || defined (OS_LINUX)	/* VxWorks and Linux */
-
-extern unsigned long nsc_asm_msr_vsa_rd(unsigned long, unsigned long *,
-					unsigned long *);
-extern unsigned long nsc_asm_msr_vsa_wr(unsigned long, unsigned long,
-					unsigned long);
-
-void
-gfx_msr_asm_read(unsigned short msrReg, unsigned long msrAddr,
-		 unsigned long *ptrHigh, unsigned long *ptrLow)
-{
-   unsigned long addr, val1, val2;
-
-   addr = msrAddr | (unsigned long)msrReg;
-   nsc_asm_msr_vsa_rd(addr, &val2, &val1);
-   *ptrHigh = val2;
-   *ptrLow = val1;
-}
-
-void
-gfx_msr_asm_write(unsigned short msrReg, unsigned long msrAddr,
-		  unsigned long *ptrHigh, unsigned long *ptrLow)
-{
-   unsigned long addr, val1, val2;
-
-   val2 = *ptrHigh;
-   val1 = *ptrLow;
-   addr = (msrAddr & 0xFFFF0000) | (unsigned long)msrReg;
-   nsc_asm_msr_vsa_wr(addr, val2, val1);
-}
-
-unsigned char
-gfx_inb(unsigned short port)
-{
-   unsigned char value;
-   __asm__ volatile ("inb %1,%0":"=a" (value):"d"(port));
-
-   return value;
-}
-
-unsigned short
-gfx_inw(unsigned short port)
-{
-   unsigned short value;
-   __asm__ volatile ("in %1,%0":"=a" (value):"d"(port));
-
-   return value;
-}
-
-unsigned long
-gfx_ind(unsigned short port)
-{
-   unsigned long value;
-   __asm__ volatile ("inl %1,%0":"=a" (value):"d"(port));
-
-   return value;
-}
-
-void
-gfx_outb(unsigned short port, unsigned char data)
-{
-   __asm__ volatile ("outb %0,%1"::"a" (data), "d"(port));
-}
-
-void
-gfx_outw(unsigned short port, unsigned short data)
-{
-   __asm__ volatile ("out %0,%1"::"a" (data), "d"(port));
-}
-
-void
-gfx_outd(unsigned short port, unsigned long data)
-{
-   __asm__ volatile ("outl %0,%1"::"a" (data), "d"(port));
-}
-
-#elif defined(XFree86Server)
-
 #include <compiler.h>
 #define INB(port) inb(port)
 #define INW(port) inw(port)
@@ -611,56 +396,6 @@ gfx_msr_asm_write(unsigned short msrReg, unsigned long msrAddr,
    nsc_asm_msr_vsa_wr(addr, val2, val1);
 #endif
 }
-#else /* else nothing */
-
-unsigned char
-gfx_inb(unsigned short port)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-   return (0);
-}
-
-unsigned short
-gfx_inw(unsigned short port)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-   return (0);
-}
-
-unsigned long
-gfx_ind(unsigned short port)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-   return (0);
-}
-
-void
-gfx_outb(unsigned short port, unsigned char data)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-}
-
-void
-gfx_outw(unsigned short port, unsigned short data)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-}
-
-void
-gfx_outd(unsigned short port, unsigned long data)
-{
-   /* ADD OS SPECIFIC IMPLEMENTATION */
-}
-#endif
-
-#ifndef XFree86Server
-#define INB(port) gfx_inb(port)
-#define INW(port) gfx_inw(port)
-#define IND(port) gfx_ind(port)
-#define OUTB(port, data) gfx_outb(port, data)
-#define OUTW(port, data) gfx_outw(port, data)
-#define OUTD(port, data) gfx_outd(port, data)
-#endif
 
 /* INITIALIZATION ROUTINES 
  * These routines are used during the initialization of the driver to 
